==> aloe-1.3.tar.gz: aloe-1.3/modules/wimax_symboldemap/src/module_imp.c <==
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  FILE:        simboldemap_imp.c                                                     	//
//                                                                                      //
//                                                                                      //
//  Description: Simbol mapping 				         		//
//               									//
//                            								//
//							                                //
//  Input:	 control_flow_in; data_flow_in                                          //
//                                                                                      //
//  Output:      data_flow_out                                                          //
//                                                                                      //
//June 2009                                                                             //
//////////////////////////////////////////////////////////////////////////////////////////


/** ALOE headers
 */
#include <phal_sw_api.h>
#include <math.h>
#include <swapi_utils.h>


#include "inputs.h"
#include "outputs.h"
#include "stats.h"

#include "typetools.h"
#include "symboldemap_code.h"
#include "CSymboldemap.h"


#define NUMBITSBYTE	8

/*GLOBAL VARIABLES*/
int data_rcved;		//Data received-->data_rcved=1
			//Data non received-->data_rcved=0

int bufferB[INPUT_MAX_DATA];


/*PREDEFINED FUNCTIONS*/
void Init_Controlfunction();
int datainflow_bypass(int len);


//////////////////////////////////////////////////////////////////////////////////////////
//SQUELETON CALLED FUNCTIONS//////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
//CONTROL ////////////////////////////////////////////////////////////////////////CONTROL/
//////////////////////////////////////////////////////////////////////////////////////////
//INPUT///////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length(in control in type words) of the expected control flow at each 	*/
/*time-slot										*/
/*Funtion activated if control flow has been received					*/					
/*Check INPUT_MAX_CONTROL								*/
int get_controlin_length(){
    	return(INPUT_MAX_CONTROL);
}

/*Process the received control flow according to the length returned by 		*/
/*get_controlin_length()								*/
/*"len" indicates the number of control words to be processed				*/
int process_inputcontrol(int len){
int i;

	if(len==1){
		printf("O---->SIMBOL DEMAP (config): TSLOT%d, STATUS=%d\n",\
			control_simboldemap.CExec.timeslot,\
			control_simboldemap.CExec.status);
		printf("O       NumInputdata=%d, NumOutputdata=%d\n",\
				control_simboldemap.CData.ninputdata,\
				control_simboldemap.CData.noutputdata); 
		printf("O       modulation=%d (1: BPSK, 2: QPSK, 4:16QAM, 6:64QAM \n",\
				control_simboldemap.CData.modulation);
		
		
	}
return(1);	/*return 1 if OK; return 0 if error*/
}

//////////////////////////////////////////////////////////////////////////////////////////
//OUTPUT//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length (in control out type words) of the generated control flow at each	*/
/*time-slot										*/
/*Check OUTPUT_MAX_CONTROL								*/
int get_controlout_length(){
int length=1;

    return(length);
}

/*Generate the control word to be send according the length provided by 		*/
/*get_controlout_length()								*/
/*"len" indicates the number of control words to be generated				*/
int generate_outputcontrol(int len){
/*return 1 if OK; return 0 if error*/
return(1);
}



//////////////////////////////////////////////////////////////////////////////////////////
//DATA/////////////////////////////////////////////////////////////////////////////DATA///
//////////////////////////////////////////////////////////////////////////////////////////
//INPUT///////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length(in data in type words) of the expected data flow at each time-slot	*/
//Funtion activated only if data flow has been received					*/
/*Check INPUT_MAX_DATA									*/
int get_datain_length()
{
int length=0;

	if(control_simboldemap.CExec.status==NONACTIVE)length=0;
	if(control_simboldemap.CExec.status==ACTIVE)length=\
				control_simboldemap.CData.ninputdata;
	if(control_simboldemap.CExec.status==TEST_FLOW)length=\
				control_simboldemap.CData.ninputdata;
	if(control_simboldemap.CExec.status==TEST_PROCESS)length=\
				control_simboldemap.CData.ninputdata;
				
	//printf("SYMBOLDEMAP.get_datain_length(): length=%d\n", length);
    	return(length);
}
/*Process the received data flow according to the length returned by get_datain_length()*/
/** Run function. return 1 if ok, 0 if error						*/
/*"len" indicates the number of data words to be processed				*/
int process_inputdata(int len)
{
	data_rcved=1;	//The execution of this function implies that enough data has 
			//been received
	
	printf("SYMBOLDEMAP.process_inputdata(): length=%d\n", len);
	//Testing flows purposes
	if(control_simboldemap.CExec.status==TEST_FLOW)datainflow_bypass(len);
	//Testing module processing functionality
	if(control_simboldemap.CExec.status==TEST_PROCESS)test_simboldemap();
	//Normal modules execution
	if(control_simboldemap.CExec.status==ACTIVE)process_datainflow(len);
	return 1;	
}


//////////////////////////////////////////////////////////////////////////////////////////
//OUTPUT//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length (in data out type words) of the generated data flow at each	*/
/*time-slot										*/
int get_dataout_length()
{
int length;

	length=0;
	if(data_rcved==0)return(length);
	data_rcved=0;
	//Testing flows purposes
	if(control_simboldemap.CExec.status==TEST_FLOW)
		length=control_simboldemap.CData.ninputdata;	//Data send=Data received
	//Testing module processing functionality
	if(control_simboldemap.CExec.status==TEST_PROCESS)
		length=control_simboldemap.CData.ninputdata;					//No data send
	//Normal execution
	if(control_simboldemap.CExec.status==ACTIVE)	
		length=dataout_length();
    	return(length);
}


/*Generate the control word to be send according the length provided by 		*/
/*get_controlout_length()								*/
/** Run function. return 1 if ok, 0 if error						*/
/*"len" indicates the number of data words to be generated				*/
int generate_outputdata(int len)
{
	return 1;
}



int InitCustom()
{
    return 1;
}

int RunCustom()
{
    return 1;
}
void ConfigInterfaces()
{
}


//////////////////////////////////////////////////////////////////////////////////////////
//END SQUELETON CALLED FUNCTIONS//////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
//######################################################################################//
//////////////////////////////////////////////////////////////////////////////////////////
//ESPECIFIC MODULE FUNCTIONS//////////////////////////////////////////////////////////////
//CONTROL////////////////////////////////////////////////////////////////////////CONTROL//
//////////////////////////////////////////////////////////////////////////////////////////
void Init_Controlfunction()
{
	control_simboldemap.CExec.status=NONACTIVE;
	control_simboldemap.CData.ninputdata=0;
	control_simboldemap.CData.noutputdata=0;
}

//////////////////////////////////////////////////////////////////////////////////////////
//DATA//////////////////////////////////////////////////////////////////////////////DATA//
//////////////////////////////////////////////////////////////////////////////////////////

/*Perfom a bypass input output without any data modification*/
int datainflow_bypass(int len)
{
int i;
int info_C[INPUT_MAX_DATA];

	printf("simboldemap: datainflow_bypass() NON VALID OPTION-TO ARRANGE\n");

/*	if(len>=INPUT_MAX_DATA)printf("simboldemap(datainflow_bypass)ERROR len > INPUT_MAX_DATA\n");
//	printf("simboldemap BYPASS\n");
	for(i=1; i<len; i++){
		output_data[i-1]=input_data[i-1];
//		printf("%d \n", output_data[i-1]);
//		if(i%32==0)printf("\n");
		}
//	printf("\n");
	//printf("simboldemap(datainflow_bypass): output length=%d\n", len);
*/
	return(1);
}



int process_datainflow(int length)
{
int i, dvalid, new_ch_len;
static int one=0;
//symbolIN bufferCH[INPUT_MAX_DATA];

	printf("SYMBOLDEMAP.process_datainflow(): length=%d\n", length);
						
	//DONWLOAD DATA
	//for(i=0; i<length; i++)bufferCH[i]=(char)input_data[i];
	
	//CHAR TO BITS	
	//length=MSBfirstchar2bin (bufferCH, bufferB, length);
	
	//PRINT INPUT	
	printf("SYMBOL DEMAPPING process_datainflow() INPUT length=%d\n", length);					
/*	for(i=1; i<=length; i++){
		printf("%4.2f %4.2f  ", input_data[i-1].re, input_data[i-1].im);
		if(i%16 == 0)printf("\n");
	}
	printf("\n");
*/	
	//SYMBOL DEMAPPING
	symboldemap(control_simboldemap.CData.modulation,\
			length,\
			(symbol *)input_data,\
			&new_ch_len,\
			output_data);
	
	//PRINT OUTPUT	
	if(one==0){
		printf("SYMBOL DEMAPPING process_datainflow() OUTPUT\n");				
		for(i=1; i<=new_ch_len; i++){
			printf("%4.2f", output_data[i-1]);
			if(i%16 == 0)printf("\n");
		}
		printf("\n");
	one=1;
	}
        printf("SYMBOL DEMAP.process_datainflow(): length=%d\n", length);
	return(1);

}

int dataout_length()
{
int length;

	length=control_simboldemap.CData.noutputdata;
	//printf("INTERLEAVER: dataout_length: length=%d\n", length);
	return(length);
}

int generate_dataflow(int len)
{
int i;
	return(1);
}



int test_simboldemap(int length)
{

/*int i, dvalid, error;

unsigned char bufferCH[INPUT_MAX_DATA];
	
	Ncpc=2;
	Ncbps=384;
	
	
	dvalid=check_interleaver_params(Ncbps, Ncpc);
	
	if(dvalid==0)printf("ERROR: dvalid=%d\n", dvalid);
	if(Ncbps>=(INPUT_MAX_DATA*8))printf("ERROR: test_interlaever() Ncbps out of range\n");
	
	printf("INTERLEAVER: test_interleaver(1) Ncbps=%d Ncpc=%d length=%d\n",\
							Ncbps, Ncpc, length);
	//DATA GENERATION						
	for(i=0; i<Ncbps/8; i++)bufferAO[i]=i;	
	//PRINT INPUT DATA					
	for(i=1; i<=(Ncbps/8); i++){
		printf("% d", bufferAO[i-1]);
		if(i%32 == 0)printf("\n");
	}
	printf("\n");	
	//CHAR TO BITs
	for(i=0; i<Ncbps; i++)bufferCH[i]=(char)bufferAO[i];
	length=MSBfirstchar2bin (bufferCH, bufferB, Ncbps/8);
	//INTERLEAVING
	interleaving(Ncbps, Ncpc, 0, dvalid, bufferB, bufferA);
	//DEINTERLEAVING
	deinter (Ncbps, Ncpc, dvalid, bufferA, bufferB);
	//BITS TO CHARS
	length=MSBfirstbin2char (bufferB, bufferCH, Ncbps);	
	printf("DEINTERLEAVER: test Ncbps=%d Ncpc=%d length=%d dvalid=%d\n",\
						Ncbps, Ncpc, length, dvalid);
	//PRINT OUTPUT					
	for(i=1; i<=(Ncbps/8); i++){
		printf("% d", bufferCH[i-1]);
		if(i%32 == 0)printf("\n");
	}
	printf("\n");
        
	//CHECK ERRORS
	error=0;
	for(i=0; i<Ncbps/8; i++){
		if(bufferCH[i] != (char)bufferAO[i])error++;
	}
	if(error==0)printf("TEST_INTERLEAVING-DEINTERLEAVING OK\n");
	if(error>0)printf("TEST_INTERLEAVING-DEINTERLEAVING NOK\n");

*/
	return(1);
}

//////////////////////////////////////////////////////////////////////////////////////////
//END OF ESPECIFIC MODULE FUNCTIONS///////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/wimax_symboldemap/src/module_imp.c <==
////////////////////////////////////////////////////////////////////////////////
//                                                                            //
//  MODULE:        simboldemap                                                //
//                                                                            //
//                                                                            //
//  Description: Simbol mapping 				              //
//               							      //
//                            						      //
//							                      //
//                                                                            //
//June 2009                                                                   //
////////////////////////////////////////////////////////////////////////////////


/** ALOE headers
 */
#include <phal_sw_api.h>
#include <math.h>
#include <swapi_utils.h>

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"

#include "typetools.h"
#include "symboldemap_code.h"



#define NUMBITSBYTE	8

/*GLOBAL VARIABLES*/
int data_rcved;		//Data received-->data_rcved=1
			//Data non received-->data_rcved=0

int bufferB[INPUT_MAX_DATA];


/*PREDEFINED FUNCTIONS*/
void Init_Controlfunction();
int datainflow_bypass(int len);


//////////////////////////////////////////////////////////////////////////////////////////
//SQUELETON CALLED FUNCTIONS//////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
//CONTROL ////////////////////////////////////////////////////////////////////////CONTROL/
//////////////////////////////////////////////////////////////////////////////////////////
//INPUT///////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length(in control in type words) of the expected control flow at each 	*/
/*time-slot										*/
/*Funtion activated if control flow has been received					*/					
/*Check INPUT_MAX_CONTROL								*/
int get_controlin_length(){
    	return(INPUT_MAX_CONTROL);
}

/*Process the received control flow according to the length returned by 		*/
/*get_controlin_length()								*/
/*"len" indicates the number of control words to be processed				*/
int process_inputcontrol(int len){
int i;

	if(len==1){
		printf("O---->SIMBOL DEMAP (config): TSLOT%d, STATUS=%d\n",\
			control_simboldemap.CExec.timeslot,\
			control_simboldemap.CExec.status);
		printf("O       NumInputdata=%d, NumOutputdata=%d\n",\
				control_simboldemap.CData.ninputdata,\
				control_simboldemap.CData.noutputdata); 
		printf("O       modulation=%d (1: BPSK, 2: QPSK, 4:16QAM, 6:64QAM \n",\
				control_simboldemap.CData.modulation);
		
		
	}
return(1);	/*return 1 if OK; return 0 if error*/
}

//////////////////////////////////////////////////////////////////////////////////////////
//OUTPUT//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length (in control out type words) of the generated control flow at each	*/
/*time-slot										*/
/*Check OUTPUT_MAX_CONTROL								*/
int get_controlout_length(){
int length=1;

    return(length);
}

/*Generate the control word to be send according the length provided by 		*/
/*get_controlout_length()								*/
/*"len" indicates the number of control words to be generated				*/
int generate_outputcontrol(int len){
/*return 1 if OK; return 0 if error*/
return(1);
}



//////////////////////////////////////////////////////////////////////////////////////////
//DATA/////////////////////////////////////////////////////////////////////////////DATA///
//////////////////////////////////////////////////////////////////////////////////////////
//INPUT///////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length(in data in type words) of the expected data flow at each time-slot	*/
//Funtion activated only if data flow has been received					*/
/*Check INPUT_MAX_DATA									*/
int get_datain_length()
{
int length=0;

	if(control_simboldemap.CExec.status==NONACTIVE)length=0;
	if(control_simboldemap.CExec.status==ACTIVE)length=\
				control_simboldemap.CData.ninputdata;
	if(control_simboldemap.CExec.status==TEST_FLOW)length=\
				control_simboldemap.CData.ninputdata;
	if(control_simboldemap.CExec.status==TEST_PROCESS)length=\
				control_simboldemap.CData.ninputdata;
				
    	return(length);
}
/*Process the received data flow according to the length returned by get_datain_length()*/
/** Run function. return 1 if ok, 0 if error						*/
/*"len" indicates the number of data words to be processed				*/
int process_inputdata(int len)
{
	data_rcved=1;	//The execution of this function implies that enough data has 
			//been received
	
	//Testing flows purposes
	if(control_simboldemap.CExec.status==TEST_FLOW)datainflow_bypass(len);
	//Testing module processing functionality
	if(control_simboldemap.CExec.status==TEST_PROCESS)test_simboldemap();
	//Normal modules execution
	if(control_simboldemap.CExec.status==ACTIVE)process_datainflow(len);
	return 1;	
}


//////////////////////////////////////////////////////////////////////////////////////////
//OUTPUT//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

/*Returns the length (in data out type words) of the generated data flow at each	*/
/*time-slot										*/
int get_dataout_length()
{
int length;

	length=0;
	if(data_rcved==0)return(length);
	data_rcved=0;
	//Testing flows purposes
	if(control_simboldemap.CExec.status==TEST_FLOW)
		length=control_simboldemap.CData.ninputdata;	//Data send=Data received
	//Testing module processing functionality
	if(control_simboldemap.CExec.status==TEST_PROCESS)
		length=control_simboldemap.CData.ninputdata;					//No data send
	//Normal execution
	if(control_simboldemap.CExec.status==ACTIVE)	
		length=dataout_length();
    	return(length);
}


/*Generate the control word to be send according the length provided by 		*/
/*get_controlout_length()								*/
/** Run function. return 1 if ok, 0 if error						*/
/*"len" indicates the number of data words to be generated				*/
int generate_outputdata(int len)
{
	return 1;
}



int InitCustom()
{
    return 1;
}

int RunCustom()
{
    return 1;
}
void ConfigInterfaces()
{
}


//////////////////////////////////////////////////////////////////////////////////////////
//END SQUELETON CALLED FUNCTIONS//////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
//######################################################################################//
//////////////////////////////////////////////////////////////////////////////////////////
//ESPECIFIC MODULE FUNCTIONS//////////////////////////////////////////////////////////////
//CONTROL////////////////////////////////////////////////////////////////////////CONTROL//
//////////////////////////////////////////////////////////////////////////////////////////
void Init_Controlfunction()
{
	control_simboldemap.CExec.status=NONACTIVE;
	control_simboldemap.CData.ninputdata=0;
	control_simboldemap.CData.noutputdata=0;
}

//////////////////////////////////////////////////////////////////////////////////////////
//DATA//////////////////////////////////////////////////////////////////////////////DATA//
//////////////////////////////////////////////////////////////////////////////////////////

/*Perfom a bypass input output without any data modification*/
int datainflow_bypass(int len)
{
int i;
int info_C[INPUT_MAX_DATA];

	printf("simboldemap: datainflow_bypass() NON VALID OPTION\n");
	return(1);
}



int process_datainflow(int length)
{
int i, dvalid, new_ch_len;
static int one1=1;
static int one2=1;
static int count1=0;
static int count2=0;
	
	//SYMBOL DEMAPPING
	new_ch_len=symboldemap(control_simboldemap.CData.modulation,\
			length,\
			(symbol *)input_data,\
			output_data);
	
	//PRINT OUTPUT
/*        new_ch_len=64;
        one2++;
	if(one2==20){
                printf("SYMBOL DEMAPPING new_ch_len=%d OUTPUT\n", new_ch_len);
                //printf("MOD=%d\n", control_simboldemap.CData.modulation);
		for(i=1; i<=new_ch_len; i++){
			printf(" %4.1f ", output_data[i-1]);
			if(i%16 == 0)printf("\n");
		}
		printf("\n");
	//one=1;
	}
 */
	return(1);

}

int dataout_length()
{
int length;

	length=control_simboldemap.CData.noutputdata;
	return(length);
}

int generate_dataflow(int len)
{
int i;
	return(1);
}



int test_simboldemap(int length)
{
        printf("simboldemap: test_simboldemap() NON VALID OPTION\n");
	return(1);
}



//////////////////////////////////////////////////////////////////////////////////////////
//END OF ESPECIFIC MODULE FUNCTIONS///////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
